##  Updating Processes as Application Lifecycles Evolve
  1. In SAP LeanIX, check for applications that are nearing the end of their active phase or have recently entered the phase-out stage. In the inventory, you can easily list the fact sheets by applying lifecycle filters. For more details, see [Using the Lifecycle Filter](https://help.sap.com/docs/leanix/ea/advanced-filter-options?locale=en-US&state=PRODUCTION&version=CLOUD "Advanced filter options provide powerful ways to refine searches and manage fact sheets. These options allow for complex queries, making it easier to find and organize specific architectural elements within your IT landscape.").
  2. Identify related processes in SAP LeanIX and compile an inventory list along with the respective process owners. Note that you must have synchronized process owner information from SAP Signavio by creating a custom field on business context (process) fact sheets.
  3. Contact the process owners to convey the relevant successor applications once the decision has been made.
